package stockquote;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.StreamTokenizer;
import java.net.URL;

/**
 * This sample is a Java class that gets a stock price quote given a symbol.
 */
public class StockQuoteService 
{
  /**
  * Gets the price for a stock.
  * 
  * @param the String stock symbol, e.g. "IBM"
  * @return the stock price
  */

  public float getQuote(String symbol) throws Exception 
  {

    URL url = new URL(BASE_URL + symbol);
  
    // get the quote as a comma separated value string, as in the following example:
    // "IBM",80.85,"11/6/2002","2:20pm",-0.68,80.80,81.500,80.10,5697700

    InputStream is = url.openStream();
    Reader reader = new InputStreamReader(is);
    StreamTokenizer st = new StreamTokenizer(reader);
  
    // get the symbol string token, e.g. IBM
    st.nextToken();
    String outSymbol = st.sval;
    if (!symbol.equalsIgnoreCase(outSymbol)) 
    {
      throw new Exception("Wrong symbol received: " + outSymbol);
    }
  
    // skip the comma token
    st.nextToken();
  
    // get the price number token, e.g. 80.85
    st.nextToken();
    float price = (float) st.nval;
  
    reader.close();
    
    return price;
  }

  private String BASE_URL = "http://finance.yahoo.com/d/quotes.csv?f=sl1d1t1c1ohgv&e=.csv&s=";
}